current_branch

Function current_branch 

pub fn current_branch() -> Result<String>
Return the name of the current git branch.

Errors

Returns an error if the current directory is not a git repository or git is not installed.